# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/violation.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'eolymp/judge/violation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/judge/violation.proto\x12\x0c\x65olymp.judge\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf4\x01\n\tViolation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tcancelled\x18\x02 \x01(\x08\x12\x0f\n\x07summary\x18\x03 \x01(\t\x12\x11\n\tautomatic\x18\x04 \x01(\x08\x12\x16\n\x0eparticipant_id\x18\x05 \x01(\t\x12\x10\n\x08given_by\x18\n \x01(\t\x12,\n\x08given_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1aL\n\x05Patch\"C\n\x05\x46ield\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07SUMMARY\x10\x01\x12\r\n\tCANCELLED\x10\x02\x12\r\n\tAUTOMATIC\x10\x03\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.violation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_VIOLATION']._serialized_start=80
  _globals['_VIOLATION']._serialized_end=324
  _globals['_VIOLATION_PATCH']._serialized_start=248
  _globals['_VIOLATION_PATCH']._serialized_end=324
  _globals['_VIOLATION_PATCH_FIELD']._serialized_start=257
  _globals['_VIOLATION_PATCH_FIELD']._serialized_end=324
# @@protoc_insertion_point(module_scope)



from eolymp.helpdesk import ticket_pb2 as _ticket_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TicketChangedEvent(_message.Message):
    __slots__ = ("scope", "before", "after")
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    scope: str
    before: _ticket_pb2.Ticket
    after: _ticket_pb2.Ticket
    def __init__(self, scope: _Optional[str] = ..., before: _Optional[_Union[_ticket_pb2.Ticket, _Mapping]] = ..., after: _Optional[_Union[_ticket_pb2.Ticket, _Mapping]] = ...) -> None: ...

class CommentChangedEvent(_message.Message):
    __slots__ = ("ticket_id", "before", "after")
    TICKET_ID_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    ticket_id: str
    before: _ticket_pb2.Ticket.Comment
    after: _ticket_pb2.Ticket.Comment
    def __init__(self, ticket_id: _Optional[str] = ..., before: _Optional[_Union[_ticket_pb2.Ticket.Comment, _Mapping]] = ..., after: _Optional[_Union[_ticket_pb2.Ticket.Comment, _Mapping]] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Violation(_message.Message):
    __slots__ = ("id", "cancelled", "summary", "automatic", "participant_id", "given_by", "given_at")
    class Patch(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNSPECIFIED: _ClassVar[Violation.Patch.Field]
            SUMMARY: _ClassVar[Violation.Patch.Field]
            CANCELLED: _ClassVar[Violation.Patch.Field]
            AUTOMATIC: _ClassVar[Violation.Patch.Field]
        UNSPECIFIED: Violation.Patch.Field
        SUMMARY: Violation.Patch.Field
        CANCELLED: Violation.Patch.Field
        AUTOMATIC: Violation.Patch.Field
        def __init__(self) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    CANCELLED_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    GIVEN_BY_FIELD_NUMBER: _ClassVar[int]
    GIVEN_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    cancelled: bool
    summary: str
    automatic: bool
    participant_id: str
    given_by: str
    given_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., cancelled: bool = ..., summary: _Optional[str] = ..., automatic: bool = ..., participant_id: _Optional[str] = ..., given_by: _Optional[str] = ..., given_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
